@@ -22,7 +22,7 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Rod Docking.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 namespace opt {
     static unsigned max_overlap = 10;
@@ -50,8 +50,13 @@ static const struct option longopts[] = {
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... [READS]\n"
 "Assemble a single contig from reads in a single orientation.\n"
+"\n"
+" Arguments:\n"
+"\n"
 "  READS  fasta-formatted reads file: the first read is used as the seed.\n"
 "\n"
+" Options:\n"
+"\n"
 "  -o, --max_overlap=INT            maximum tier overlap for consensus calling"
 " [10]\n"
 "  -m, --max_mismatch=INT           maximum mismatches allowed for consensus"
