@@ -22,13 +22,15 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Shaun Jackman.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... [FASTA]\n"
 "Count k-mer of the specified file.\n"
 "The index file TARGET.fm will be used if present.\n"
 "\n"
+" Options:\n"
+"\n"
 "  -k, --kmer              the size of a k-mer\n"
 "  -v, --verbose           display verbose output\n"
 "      --help              display this help and exit\n"
@@ -158,8 +160,6 @@ static void readFMIndex(FMIndex& g, const string& faPath)
 
 int main(int argc, char** argv)
 {
-	checkPopcnt();
-
 	bool die = false;
 	for (int c; (c = getopt_long(argc, argv,
 					shortopts, longopts, NULL)) != -1;) {
