@@ -346,7 +346,9 @@ class Edge
 	/** Return properties of vertex u. */
 	const vertex_property_type& operator[](vertex_descriptor u) const
 	{
-		return m_vertices[index(u)].get_property();
+		vertices_size_type ui = get(vertex_index, *this, u);
+		assert(ui < num_vertices());
+		return m_vertices[ui].get_property();
 	}
 
 	/** Returns an iterator-range to the vertices. */
@@ -371,8 +373,9 @@ class Edge
 	std::pair<out_edge_iterator, out_edge_iterator>
 	out_edges(vertex_descriptor u) const
 	{
-		assert(index(u) < num_vertices());
-		return m_vertices[index(u)].out_edges(u);
+		vertices_size_type ui = get(vertex_index, *this, u);
+		assert(ui < num_vertices());
+		return m_vertices[ui].out_edges(u);
 	}
 
 	/** Returns an iterator-range to the adjacent vertices of
@@ -380,8 +383,9 @@ class Edge
 	std::pair<adjacency_iterator, adjacency_iterator>
 	adjacent_vertices(vertex_descriptor u) const
 	{
-		assert(index(u) < num_vertices());
-		return m_vertices[index(u)].adjacent_vertices();
+		vertices_size_type ui = get(vertex_index, *this, u);
+		assert(ui < num_vertices());
+		return m_vertices[ui].adjacent_vertices();
 	}
 
 	/** Adds edge (u,v) to this graph. */
@@ -389,16 +393,19 @@ class Edge
 	add_edge(vertex_descriptor u, vertex_descriptor v,
 			const edge_property_type& ep = edge_property_type())
 	{
-		assert(index(u) < num_vertices());
-		assert(index(v) < num_vertices());
+		vertices_size_type ui = get(vertex_index, *this, u);
+		assert(ui < num_vertices());
+		assert(get(vertex_index, *this, v) < num_vertices());
 		return make_pair(edge_descriptor(u, v),
-				m_vertices[index(u)].add_edge(v, ep));
+				m_vertices[ui].add_edge(v, ep));
 	}
 
 	/** Remove the edge (u,v) from this graph. */
 	void remove_edge(vertex_descriptor u, vertex_descriptor v)
 	{
-		m_vertices[index(u)].remove_edge(v);
+		vertices_size_type ui = get(vertex_index, *this, u);
+		assert(ui < num_vertices());
+		m_vertices[ui].remove_edge(v);
 	}
 
 	/** Remove the edge e from this graph. */
@@ -410,7 +417,9 @@ class Edge
 	/** Remove all out edges from vertex u. */
 	void clear_out_edges(vertex_descriptor u)
 	{
-		m_vertices[index(u)].clear_out_edges();
+		vertices_size_type ui = get(vertex_index, *this, u);
+		assert(ui < num_vertices());
+		m_vertices[ui].clear_out_edges();
 	}
 
 	/** Remove all edges to and from vertex u from this graph.
@@ -424,16 +433,22 @@ class Edge
 			remove_edge(*v, u);
 	}
 
+	/** Set the vertex_removed property. */
+	void put(vertex_removed_t, vertex_descriptor u, bool flag)
+	{
+		vertices_size_type ui = get(vertex_index, *this, u);
+		if (ui >= m_removed.size())
+			m_removed.resize(ui + 1);
+		m_removed[ui] = flag;
+	}
+
 	/** Remove vertex u from this graph. It is assumed that there
 	 * are no edges to or from vertex u. It is best to call
 	 * clear_vertex before remove_vertex.
 	 */
 	void remove_vertex(vertex_descriptor u)
 	{
-		unsigned i = index(u);
-		if (i >= m_removed.size())
-			m_removed.resize(i + 1);
-		m_removed[i] = true;
+		put(vertex_removed, u, true);
 	}
 
 	/** Return the number of vertices. */
@@ -455,7 +470,9 @@ class Edge
 	/** Return the out degree of vertex u. */
 	degree_size_type out_degree(vertex_descriptor u) const
 	{
-		return m_vertices[index(u)].out_degree();
+		vertices_size_type ui = get(vertex_index, *this, u);
+		assert(ui < num_vertices());
+		return m_vertices[ui].out_degree();
 	}
 
 	/** Return the nth vertex. */
@@ -478,28 +495,26 @@ class Edge
 	std::pair<edge_descriptor, bool> edge(
 			vertex_descriptor u, vertex_descriptor v) const
 	{
-		unsigned i = index(u);
-		assert(i < m_vertices.size());
+		vertices_size_type ui = get(vertex_index, *this, u);
+		assert(ui < num_vertices());
 		return make_pair(edge_descriptor(u, v),
-				m_vertices[i].edge(v));
-	}
-
-	/** Return true if this vertex has been removed. */
-	bool get(vertex_removed_t, vertex_descriptor u) const
-	{
-		return is_removed(u);
+				m_vertices[ui].edge(v));
 	}
 
 	/** Return properties of edge e. */
 	edge_property_type& operator[](edge_descriptor e)
 	{
-		return m_vertices[index(e.first)][e.second];
+		vertices_size_type ui = get(vertex_index, *this, e.first);
+		assert(ui < num_vertices());
+		return m_vertices[ui][e.second];
 	}
 
 	/** Return properties of edge e. */
 	const edge_property_type& operator[](edge_descriptor e) const
 	{
-		return m_vertices[index(e.first)][e.second];
+		vertices_size_type ui = get(vertex_index, *this, e.first);
+		assert(ui < num_vertices());
+		return m_vertices[ui][e.second];
 	}
 
 	/** Remove edges that satisfy the predicate. */
@@ -512,14 +527,14 @@ class Edge
 			it->remove_edge_if(vertex(i++), predicate);
 	}
 
-  private:
 	/** Return true if this vertex has been removed. */
 	bool is_removed(vertex_descriptor u) const
 	{
-		unsigned i = index(u);
-		return i < m_removed.size() ? m_removed[i] : false;
+		vertices_size_type ui = get(vertex_index, *this, u);
+		return ui < m_removed.size() ? m_removed[ui] : false;
 	}
 
+  private:
 	DirectedGraph& operator =(const DirectedGraph& x);
 
 	/** The set of vertices. */
@@ -698,19 +713,18 @@ remove_edge_if(Predicate predicate, DirectedGraph<VP, EP>& g)
 
 /** Return true if this vertex has been removed. */
 template <typename VP, typename EP>
-bool get(vertex_removed_t tag, const DirectedGraph<VP, EP>& g,
+bool get(vertex_removed_t, const DirectedGraph<VP, EP>& g,
 		typename DirectedGraph<VP, EP>::vertex_descriptor u)
 {
-	return g.get(tag, u);
+	return g.is_removed(u);
 }
 
 template <typename VP, typename EP>
-void put(vertex_removed_t, DirectedGraph<VP, EP>& g,
+void put(vertex_removed_t tag, DirectedGraph<VP, EP>& g,
 		typename DirectedGraph<VP, EP>::vertex_descriptor u,
-		bool removed)
+		bool flag)
 {
-	assert(removed);
-	return g.remove_vertex(u);
+	g.put(tag, u, flag);
 }
 
 /** Return the properties of the edge of iterator eit. */
@@ -740,6 +754,32 @@ get(edge_bundle_t, const DirectedGraph<VP, EP>& g,
 	return g[e];
 }
 
+// PropertyGraph vertex_index
+
+namespace boost {
+template <typename VP, typename EP>
+struct property_map<DirectedGraph<VP, EP>, vertex_index_t>
+{
+	typedef ContigNodeIndexMap type;
+	typedef type const_type;
+};
+}
+
+template <typename VP, typename EP>
+ContigNodeIndexMap
+get(vertex_index_t, const DirectedGraph<VP, EP>&)
+{
+	return ContigNodeIndexMap();
+}
+
+template <typename VP, typename EP>
+ContigNodeIndexMap::reference
+get(vertex_index_t tag, const DirectedGraph<VP, EP>& g,
+		typename DirectedGraph<VP, EP>::vertex_descriptor u)
+{
+	return get(get(tag, g), u);
+}
+
 // VertexMutablePropertyGraph
 
 template <typename VP, typename EP>
@@ -762,4 +802,21 @@ add_edge(
 	return g.add_edge(u, v, ep);
 }
 
+// NamedGraph
+
+template <typename VP, typename EP>
+typename DirectedGraph<VP, EP>::vertex_descriptor
+find_vertex(const std::string& name, const DirectedGraph<VP, EP>&)
+{
+	return find_vertex(name, g_contigNames);
+}
+
+template <typename VP, typename EP>
+typename DirectedGraph<VP, EP>::vertex_descriptor
+find_vertex(const std::string& name, bool sense,
+		const DirectedGraph<VP, EP>&)
+{
+	return find_vertex(name, sense, g_contigNames);
+}
+
 #endif
