@@ -1,7 +1,7 @@
 #ifndef DOTIO_H
 #define DOTIO_H 1
 
-#include "ContigID.h" // for ContigID::lock
+#include "ContigID.h" // for g_contigNames.lock
 #include "Graph/Options.h"
 #include "IOUtil.h"
 #include <boost/graph/graph_traits.hpp>
@@ -17,7 +17,8 @@ void write_vertex(std::ostream& out, const Graph& g,
 		typename graph_traits<Graph>::vertex_descriptor u,
 		const VertexProp*)
 {
-	out << '"' << u << "\" [" << get(vertex_bundle, g, u) << "]\n";
+	out << '"' << get(vertex_name, g, u) << "\""
+		" [" << get(vertex_bundle, g, u) << "]\n";
 }
 
 template <typename Graph>
@@ -40,9 +41,8 @@ void write_edges(std::ostream& out, const Graph& g,
 	std::pair<out_edge_iterator, out_edge_iterator>
 		adj = out_edges(u, g);
 	for (out_edge_iterator e = adj.first; e != adj.second; ++e) {
-		vertex_descriptor v = target(*e, g);
-		assert(!get(vertex_removed, g, v));
-		out << '"' << u << "\" -> \"" << v << '"';
+		assert(!get(vertex_removed, g, target(*e, g)));
+		out << get(edge_name, g, *e);
 		const edge_property_type& ep = get(edge_bundle, g, e);
 		if (!(ep == edge_property_type()))
 			out << " [" << ep << ']';
@@ -60,13 +60,13 @@ void write_edges(std::ostream& out, const Graph& g,
 	unsigned outdeg = out_degree(u, g);
 	if (outdeg == 0)
 		return;
-	out << '"' << u << "\" ->";
+	out << '"' << get(vertex_name, g, u) << "\" ->";
 	if (outdeg > 1)
 		out << " {";
 	std::pair<adjacency_iterator, adjacency_iterator>
 		adj = adjacent_vertices(u, g);
 	for (adjacency_iterator v = adj.first; v != adj.second; ++v)
-		out << " \"" << *v << '"';
+		out << " \"" << get(vertex_name, g, *v) << '"';
 	if (outdeg > 1)
 		out << " }";
 	out << '\n';
@@ -140,12 +140,13 @@ std::istream& read_dot_name(std::istream& in, std::string& s)
 }
 
 /** Read a vertex descriptor delimited by double quotes. */
-template <typename VertexDescriptor>
-std::istream& read_dot_id(std::istream& in, VertexDescriptor& u)
+template <typename Graph>
+std::istream& read_dot_id(std::istream& in, const Graph& g,
+		typename graph_traits<Graph>::vertex_descriptor& u)
 {
 	std::string s;
 	if (read_dot_name(in, s))
-		u = VertexDescriptor(s);
+		u = find_vertex(s, g);
 	return in;
 }
 
@@ -176,12 +177,16 @@ std::istream& read_dot(std::istream& in, Graph& g, BetterEP betterEP)
 		switch (in.peek()) {
 		  case 'g': {
 			// Graph Properties
-			unsigned k;
-			in >> expect("graph [ k =") >> k >> Ignore(']');
-			assert(in);
-			if (opt::k > 0)
-				assert(k == opt::k);
-			opt::k = k;
+			in >> expect("graph [ ");
+			if (in.peek() == 'k') {
+				unsigned k;
+				in >> expect("k =") >> k;
+				assert(in);
+				if (opt::k > 0)
+					assert(k == opt::k);
+				opt::k = k;
+			}
+			in >> Ignore(']');
 			break;
 		  }
 		  case 'e': // edge
@@ -207,8 +212,9 @@ std::istream& read_dot(std::istream& in, Graph& g, BetterEP betterEP)
 				vertex_descriptor u = add_vertex(g);
 				put(vertex_name, g, u, uname);
 			} else {
-				vertex_descriptor u(uname);
+				vertex_descriptor u = find_vertex(uname, g);
 				assert(get(vertex_index, g, u) < num_vertices(g));
+				(void)u;
 			}
 		} else if (c == '[') {
 			// Vertex properties
@@ -219,21 +225,27 @@ std::istream& read_dot(std::istream& in, Graph& g, BetterEP betterEP)
 				vertex_descriptor u = add_vertex(vp, g);
 				put(vertex_name, g, u, uname);
 			} else {
-				vertex_descriptor u(uname);
+				vertex_descriptor u = find_vertex(uname, g);
 				assert(get(vertex_index, g, u) < num_vertices(g));
-				assert(g[u] == vp);
+				if (g[u] != vp) {
+					std::cerr << "error: "
+						"vertex properties do not agree: "
+						"\"" << uname << "\" "
+						"[" << g[u] << "] [" << vp << "]\n";
+					exit(EXIT_FAILURE);
+				}
 			}
 		} else if (c == '-') {
 			// Edge
 			in >> expect(">");
 			assert(in);
-			ContigID::lock();
+			g_contigNames.lock();
 
-			vertex_descriptor u(uname);
+			vertex_descriptor u = find_vertex(uname, g);
 			if (in >> std::ws && in.peek() == '{') {
 				// Subgraph
 				in >> expect("{");
-				for (vertex_descriptor v; read_dot_id(in, v);)
+				for (vertex_descriptor v; read_dot_id(in, g, v);)
 					add_edge(u, v, defaultEdgeProp, g);
 				if (in.fail())
 					in.clear();
@@ -241,8 +253,7 @@ std::istream& read_dot(std::istream& in, Graph& g, BetterEP betterEP)
 				assert(in);
 			} else {
 				vertex_descriptor v;
-				read_dot_id(in, v);
-				if (in.fail()) {
+				if (!read_dot_id(in, g, v)) {
 					in.clear();
 					std::cerr << "error: Expected `\"' and saw `"
 						<< (char)in.peek() << "'.\n";
