@@ -34,15 +34,17 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Jared Simpson and Shaun Jackman.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... QUERY... TARGET\n"
 "Align the sequences of the files QUERY to those of TARGET.\n"
 "All perfect matches of at least k bases will be found.\n"
 "\n"
+" Options:\n"
+"\n"
 "  -k, -l, --kmer=N      k-mer size and minimum alignment length\n"
-"  -s, --section=S/N     split the target into N sections and align"
+"  -s, --section=S/N     split the target into N sections and align\n"
 "                        reads to section S [1/1]\n"
 "  -i, --ignore-multimap ignore duplicate k-mer in the target\n"
 "                        [default]\n"
