@@ -19,6 +19,7 @@
 #include <stdint.h>
 #include <string>
 #include <utility>
+#include <queue>
 #if _OPENMP
 # include <omp.h>
 #endif
@@ -31,18 +32,25 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Shaun Jackman.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... QUERY... TARGET\n"
 "Map the sequences of the files QUERY to those of the file TARGET.\n"
 "The index files TARGET.fai and TARGET.fm will be used if present.\n"
 "\n"
+" Options:\n"
+"\n"
 "  -l, --min-align=N       find matches at least N bp [1]\n"
 "  -j, --threads=N         use N parallel threads [1]\n"
 "  -s, --sample=N          sample the suffix array [1]\n"
 "  -d, --dup               identify and print duplicate sequence\n"
 "                          IDs between QUERY and TARGET\n"
+"      --order             print alignments in the same order as\n"
+"                          read from QUERY\n"
+"      --no-order          print alignments ASAP [default]\n"
+"      --chastity          discard unchaste reads\n"
+"      --no-chastity       do not discard unchaste reads [default]\n"
 "  -v, --verbose           display verbose output\n"
 "      --help              display this help and exit\n"
 "      --version           output version information and exit\n"
@@ -62,6 +70,8 @@ namespace opt {
 	/** Identify duplicate and subsumed sequences. */
 	static bool dup = false;
 
+	static int order;
+
 	/** Verbose output. */
 	static int verbose;
 }
@@ -75,7 +85,11 @@ static const struct option longopts[] = {
 	{ "min-align", required_argument, NULL, 'l' },
 	{ "dup", no_argument, NULL, 'd' },
 	{ "threads", required_argument, NULL, 'j' },
+	{ "order", no_argument, &opt::order, 1 },
+	{ "no-order", no_argument, &opt::order, 0 },
 	{ "verbose", no_argument, NULL, 'v' },
+	{ "chastity", no_argument, &opt::chastityFilter, 1 },
+	{ "no-chastity", no_argument, &opt::chastityFilter, 0 },
 	{ "help", no_argument, NULL, OPT_HELP },
 	{ "version", no_argument, NULL, OPT_VERSION },
 	{ NULL, 0, NULL, 0 }
@@ -202,6 +216,8 @@ static void printDuplicates(const Match& m, const Match& rcm,
 }
 
 
+static queue<string> g_pq;
+
 /** Return the mapping of the specified sequence. */
 static void find(const FastaIndex& faIndex, const FMIndex& fmIndex,
 		const FastqRecord& rec)
@@ -228,7 +244,14 @@ static void find(const FastaIndex& faIndex, const FMIndex& fmIndex,
 
 	SAMRecord sam = toSAM(faIndex, fmIndex, rc ? rcm : m, rc,
 			rec.seq.size());
+	if (rec.id[0] == '@') {
+		cerr << PROGRAM ": error: "
+			"the query ID `" << rec.id << "' is invalid since it "
+			"begins with `@'\n";
+		exit(EXIT_FAILURE);
+	}
 	sam.qname = rec.id;
+
 #if SAM_SEQ_QUAL
 	sam.seq = rc ? rcqseq : rec.seq;
 	sam.qual = rec.qual.empty() ? "*" : rec.qual;
@@ -242,11 +265,22 @@ static void find(const FastaIndex& faIndex, const FMIndex& fmIndex,
 		sam.mapq = 0;
 	}
 
+	bool print = opt::order == 0;
+	do {
 #pragma omp critical(cout)
-	{
-		cout << sam << '\n';
-		assert_good(cout, "stdout");
-	}
+		{
+#pragma omp critical(g_pq)
+			if (!print) {
+				print = g_pq.front() == rec.id;
+				if (print)
+					g_pq.pop();
+			}
+			if (print) {
+				cout << sam << '\n';
+				assert_good(cout, "stdout");
+			}
+		}
+	} while (!print); // spinlock :(
 
 	if (sam.isUnmapped())
 #pragma omp atomic
@@ -267,7 +301,13 @@ static void find(const FastaIndex& faIndex, const FMIndex& fmIndex,
 	for (FastqRecord rec;;) {
 		bool good;
 #pragma omp critical(in)
-		good = in >> rec;
+		{
+			good = in >> rec;
+			if (opt::order) {
+#pragma omp critical(g_pq)
+				g_pq.push(rec.id);
+			}
+		}
 		if (good)
 			find(faIndex, fmIndex, rec);
 		else
@@ -333,8 +373,6 @@ static void checkIndexes(const string& path,
 
 int main(int argc, char** argv)
 {
-	checkPopcnt();
-
 	string commandLine;
 	{
 		ostringstream ss;
@@ -344,6 +382,9 @@ int main(int argc, char** argv)
 		commandLine = ss.str();
 	}
 
+	opt::chastityFilter = false;
+	opt::trimMasked = false;
+
 	bool die = false;
 	for (int c; (c = getopt_long(argc, argv,
 					shortopts, longopts, NULL)) != -1;) {
@@ -458,8 +499,6 @@ int main(int argc, char** argv)
 	} else if (opt::verbose > 0)
 		cerr << "Identifying duplicates.\n";
 
-	opt::chastityFilter = false;
-	opt::trimMasked = false;
 	FastaInterleave fa(argv + optind, argv + argc,
 			FastaReader::FOLD_CASE);
 	find(faIndex, fmIndex, fa);
