@@ -38,15 +38,20 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Shaun Jackman.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... FASTA [OVERLAP] PATH\n"
 "Merge paths of contigs to create larger contigs.\n"
+"\n"
+" Arguments:\n"
+"\n"
 "  FASTA    contigs in FASTA format\n"
 "  OVERLAP  contig overlap graph\n"
 "  PATH     sequences of contig IDs\n"
 "\n"
+" Options:\n"
+"\n"
 "  -k, --kmer=KMER_SIZE  k-mer size\n"
 "  -o, --out=FILE        output the merged contigs to FILE [stdout]\n"
 "  -g, --graph=FILE      write the contig overlap graph to FILE\n"
@@ -560,9 +565,8 @@ int main(int argc, char** argv)
 		minCovUsed = numeric_limits<float>::infinity();
 	for (unsigned i = 0; i < contigs.size(); i++) {
 		ContigProperties vp = g[ContigNode(i, false)];
-		if (vp.coverage == 0)
+		if (vp.coverage == 0 || vp.length < opt::k)
 			continue;
-		assert((int)vp.length - opt::k + 1 > 0);
 		float cov = (float)vp.coverage / (vp.length - opt::k + 1);
 		minCov = min(minCov, cov);
 		if (seen[i])
