@@ -42,14 +42,19 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Jared Simpson and Shaun Jackman.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... LEN PATH\n"
 "Merge sequences of contigs IDs.\n"
+"\n"
+" Arguments:\n"
+"\n"
 "  LEN   lengths of the contigs\n"
 "  PATH  sequences of contig IDs\n"
 "\n"
+" Options:\n"
+"\n"
 "  -k, --kmer=KMER_SIZE  k-mer size\n"
 "  -s, --seed-length=L   minimum length of a seed contig [0]\n"
 "  -o, --out=FILE        write result to FILE\n"
