@@ -71,6 +71,10 @@ int main(int argc, char** argv)
 	MPI_Comm_rank(MPI_COMM_WORLD, &opt::rank);
 	MPI_Comm_size(MPI_COMM_WORLD, &opt::numProc);
 
+	// OMPI-1.6.1 and later reset the SIGCHLD handler so we need to
+	// reinitialize uncompress.
+	uncompress_init();
+
 	opt::parse(argc, argv);
 	if (opt::rank == 0)
 		cout << "Running on " << opt::numProc << " processors\n";
