@@ -35,14 +35,19 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Shaun Jackman.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... OVERLAP [SCAFFOLD]...\n"
 "Extend junction contigs that are supported by the scaffold graph.\n"
+"\n"
+" Arguments:\n"
+"\n"
 "  OVERLAP   the overlap graph\n"
 "  SCAFFOLD  a scaffold graph\n"
 "\n"
+" Options:\n"
+"\n"
 "  -i, --ignore=FILE     ignore junctions seen in FILE\n"
 "  -v, --verbose         display verbose output\n"
 "      --help            display this help and exit\n"
