@@ -37,15 +37,20 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Shaun Jackman.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... FASTA|OVERLAP DIST...\n"
 "Scaffold contigs using the distance estimate graph.\n"
+"\n"
+" Arguments:\n"
+"\n"
 "  FASTA    contigs in FASTA format\n"
 "  OVERLAP  the contig overlap graph\n"
 "  DIST     estimates of the distance between contigs\n"
 "\n"
+" Options:\n"
+"\n"
 "  -n, --npairs=N        minimum number of pairs [0]\n"
 "  -s, --seed-length=N   minimum contig length [200]\n"
 "          or -s N0-N1   Find the value of s in [N0,N1]\n"
@@ -107,6 +112,22 @@ static const struct option longopts[] = {
 typedef DirectedGraph<Length, DistanceEst> DG;
 typedef ContigGraph<DG> Graph;
 
+/** Return whether this edge is invalid.
+ * An edge is invalid when the overlap is larger than the length of
+ * either of its incident sequences.
+ */
+struct InvalidEdge {
+	InvalidEdge(Graph& g) : m_g(g) { }
+	bool operator()(graph_traits<Graph>::edge_descriptor e) const
+	{
+		int d = m_g[e].distance;
+		int ulength = m_g[source(e, m_g)].length;
+		int vlength = m_g[target(e, m_g)].length;
+		return d + ulength <= 0 || d + vlength <= 0;
+	}
+	const Graph& m_g;
+};
+
 /** Return whether the specified edges has sufficient support. */
 struct PoorSupport {
 	PoorSupport(Graph& g) : m_g(g) { }
@@ -705,6 +726,14 @@ int main(int argc, char** argv)
 		printGraphStats(cerr, g);
 	}
 
+	// Remove invalid edges.
+	unsigned numBefore = num_edges(g);
+	remove_edge_if(InvalidEdge(g), static_cast<DG&>(g));
+	unsigned numRemoved = numBefore - num_edges(g);
+	if (numRemoved > 0)
+		cerr << "waning: Removed "
+			<< numRemoved << " invalid edges.\n";
+
 	if (opt::minContigLengthEnd == 0) {
 		scaffold(g, opt::minContigLength, true);
 		return 0;
