@@ -30,14 +30,19 @@ static const char VERSION_MESSAGE[] =
 PROGRAM " (" PACKAGE_NAME ") " VERSION "\n"
 "Written by Jared Simpson and Shaun Jackman.\n"
 "\n"
-"Copyright 2012 Canada's Michael Smith Genome Science Centre\n";
+"Copyright 2013 Canada's Michael Smith Genome Science Centre\n";
 
 static const char USAGE_MESSAGE[] =
 "Usage: " PROGRAM " [OPTION]... ADJ DIST\n"
 "Find paths through contigs using distance estimates.\n"
+"\n"
+" Arguments:\n"
+"\n"
 "  ADJ   adjacency of the contigs\n"
 "  DIST  distance estimates between the contigs\n"
 "\n"
+" Options:\n"
+"\n"
 "  -k, --kmer=KMER_SIZE  k-mer size\n"
 "  -d, --dist-error=N    acceptable error of a distance estimate\n"
 "                        default is 6 bp\n"
